%define anolis_release 1

Summary:       PostgreSQL client library
Name:          libpq
Version:       16.1
Release:       %{anolis_release}%{?dist}

License:       PostgreSQL
Url:           http://www.postgresql.org/

Source0:       https://ftp.postgresql.org/pub/source/v%{version}/postgresql-%{version}.tar.bz2
Source1:       https://ftp.postgresql.org/pub/source/v%{version}/postgresql-%{version}.tar.bz2.sha256

# Change custom installation directories to end in /pgsql not /postgresql for RPM
#Patch1:        libpq-10.3-rpm-pgsql.patch

#Change the built-in default socket directory to be /var/run/postgresql.
#Patch2:        libpq-10.3-var-run-socket.patch

# Export symbol versioning information
#Patch3:        libpq-12.1-symbol-versioning.patch

BuildRequires: gcc make
BuildRequires: bison flex gawk gettext
BuildRequires: glibc-devel
BuildRequires: krb5-devel
BuildRequires: openssl-devel
BuildRequires: openldap-devel
BuildRequires: zlib-devel
BuildRequires: libicu-devel

Obsoletes:     postgresql-libs < 17
Provides:      postgresql-libs = %{version}-%{release}


%description
The %{name} package provides the essential shared library for any PostgreSQL
client program or interface.  You will need to install this package to use any
other PostgreSQL package or any clients that need to connect to a PostgreSQL
server.


%package devel
Summary: Development files for building PostgreSQL client tools
Requires: %{name} = %{version}-%{release}
# Historically we had 'postgresql-devel' package which was used for building
# both PG clients and PG server modules;  let's have this fake provide to cover
# most of the depending packages and the rest (those which want to build server
# modules) need to be fixed to require postgresql-server-devel package.
Provides: postgresql-devel = %{version}-%{release}
Obsoletes: postgresql-devel < 16

%description devel
The %{name}-devel package provides development files for building PostgreSQL
client tools.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n postgresql-%{version} -p1

# remove .gitignore files to ensure none get into the RPMs (bug #642210)
find . -type f -name .gitignore | xargs rm -vf

%build
# add the prefix used by PostgreSQL for symbol versioning
export SYMBOL_VERSION_PREFIX=RHPG_

# We don't build server nor client (e.g. /bin/psql) binaries in this package, so
# we can disable some configure options.
%configure \
    --enable-nls \
    --disable-rpath \
    --with-ldap \
    --with-openssl \
    --with-gssapi \
    --without-readline \
    --datadir=%_datadir/pgsql

%global build_subdirs src/include src/common src/port src/interfaces/libpq src/bin/pg_config

for subdir in %build_subdirs; do
    %make_build -C "$subdir"
done

%install
for subdir in %build_subdirs; do
    %make_install -C "$subdir"
done

find $RPM_BUILD_ROOT -name '*.a' -delete
#rm -r $RPM_BUILD_ROOT%_includedir/pgsql/server

find_lang_bins ()
{
    lst_file=$1
    binary=$2
    touch "$lst_file"
    %find_lang "$binary"-16
    cat "$binary"-16.lang >>"$lst_file"
}

find_lang_bins %name.lst        libpq5
find_lang_bins %name-devel.lst  pg_config

%generate_compatibility_deps

%files -f %name.lst
%license COPYRIGHT
%doc %_datadir/pgsql/pg_service.conf.sample
%dir %{abidir}
%_libdir/libpq.so.5*
%{abidir}/libpq*.dump
%dir %_datadir/pgsql



%files devel -f %name-devel.lst
%_bindir/pg_config
%{abidir}/pg_config-option.list
%_includedir/*
%_libdir/libpq.so
%_libdir/pkgconfig/libpq.pc

%files doc
%doc README INSTALL HISTORY
%doc doc/KNOWN_BUGS doc/TODO

%changelog
* Tue Feb 18 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 16.1-1
- Sync up from CentOS Stream libpq-16.1-1(tdawson@redhat.com)

* Mon Apr 10 2023 Kun(llfl) <llfl@linux.alibaba.com> -  15.2-3
- optimize spec file

* Tue Mar 28 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 15.2-2
- remove multilib related codes

* Mon Feb 27 2023 yuanhui <yuanhui@linux.alibaba.com> - 15.2-1
- update to 15.2
- add doc package

* Mon Oct 24 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 14.1-2
- optimise spec file

* Tue Jul 12 2022 happy_orange <songnannan@linux.alibaba.com> - 14.1-1
- Init pcakage from upstream
